@@ -43,6 +43,7 @@ from unilint.pylint_plugin import PylintPlugin
 from unilint.pychecker_plugin import PycheckerPlugin
 
 from unilint.cppcheck_plugin import CppcheckPlugin
+from unilint.cpplint_plugin import CpplintPlugin
 
 from unilint.standard_formatters import register_standard_formatters
 
@@ -57,7 +58,7 @@ register_plugin(PyflakesPlugin)
 register_plugin(PycheckerPlugin)
 register_plugin(PylintPlugin)
 register_plugin(CppcheckPlugin)
-
+register_plugin(CpplintPlugin)
 
 def setup_logger():
     logger = logging.getLogger('unilint')
