@@ -56,7 +56,8 @@ class CppcheckPlugin(AbstractCppPlugin):
                                                 ignore_returncodes=[127])
         if value == 0:
             return output
-        raise UnilintPluginInitException("ERROR Cannot find cppcheck, install via apt or pip\n%s" % message)
+        raise UnilintPluginInitException(
+            "ERROR Cannot find cppcheck, install via apt or pip\n%s" % message)
 
     def check_resource(self, options, path, type_categories):
         if not 'cpp-file' in type_categories:
@@ -84,7 +85,11 @@ class CppcheckPlugin(AbstractCppPlugin):
         if options.verbose:
             print(cmd)
 
-        _, output, _ = self.shell_cmd(cmd, shell=True, us_env=True, cwd=os.path.dirname(path), capture_std_err=True)
+        _, output, _ = self.shell_cmd(cmd,
+                                      shell=True,
+                                      us_env=True,
+                                      cwd=os.path.dirname(path),
+                                      capture_std_err=True)
 
         if options.raw:
             print output
@@ -93,13 +98,14 @@ class CppcheckPlugin(AbstractCppPlugin):
             return self.parse(output)
 
     def parse(self, output):
-        ' example output'
+        '''example output'''
         issues = []
         for line in output.splitlines():
             ignore = False
             if line.strip() == '':
                 continue
-            for prefix in ['Cppcheck - ', "Checking ", "::missingInclude:Cppcheck cannot find all the include file"]:
+            for prefix in ['Cppcheck - ', "Checking ",
+                           "::missingInclude:Cppcheck cannot find all the include file"]:
                 if line.startswith(prefix):
                     ignore = True
                     break
