@@ -13,9 +13,6 @@
 #    copyright notice, this list of conditions and the following
 #    disclaimer in the documentation and/or other materials provided
 #    with the distribution.
-#  * Neither the name of Willow Garage, Inc. nor the names of its
-#    contributors may be used to endorse or promote products derived
-#    from this software without specific prior written permission.
 #
 # THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 # "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -57,8 +54,8 @@ class PycheckerPlugin(AbstractPythonPlugin):
         raise UnilintPluginInitException("ERROR Cannot find pychecker, install via apt or pip\n%s" % message)
 
     def check_resource(self, options, path, type_categories):
-        if (not 'python-src' in type_categories and
-            not 'python-module' in type_categories):
+        if not 'python-src' in type_categories and \
+                not 'python-module' in type_categories:
             return None
 
         suppress_cmds = []
@@ -66,7 +63,7 @@ class PycheckerPlugin(AbstractPythonPlugin):
             suppress_cmds.append('--no-argsused')
             suppress_cmds.append('--no-import')
 
-        cmd = 'pychecker --only -#100 %s %s'%(' '.join(suppress_cmds), path)
+        cmd = 'pychecker --only -#100 %s %s' % (' '.join(suppress_cmds), path)
         if options.verbose:
             print(cmd)
 
